@@ -19,6 +19,7 @@
 //
 
 use std::net::{IpAddr, Ipv4Addr, SocketAddr, TcpListener};
+use std::sync::atomic::AtomicBool;
 use std::sync::Arc;
 use std::time::Duration;
 
@@ -31,11 +32,12 @@ use nucliadb_node::grpc::writer::NodeWriterGRPCDriver;
 use nucliadb_node::lifecycle;
 use nucliadb_node::replication::replicator::connect_to_primary_and_replicate;
 use nucliadb_node::replication::service::ReplicationServiceGRPCDriver;
-use nucliadb_node::settings::Settings;
+use nucliadb_node::settings::*;
 use nucliadb_node::shards::providers::unbounded_cache::AsyncUnboundedShardWriterCache;
 use nucliadb_node::utils::read_or_create_host_key;
 use nucliadb_protos::replication;
 use tempfile::TempDir;
+use tokio::sync::Notify;
 use tonic::transport::{Channel, Server};
 
 pub const SERVER_STARTUP_TIMEOUT: Duration = Duration::from_secs(5);
@@ -83,8 +85,8 @@ fn find_open_port() -> u16 {
 }
 
 pub struct NodeFixture {
-    pub settings: Arc<Settings>,
-    pub secondary_settings: Arc<Settings>,
+    pub settings: Settings,
+    pub secondary_settings: Settings,
     reader_client: Option<TestNodeReader>,
     writer_client: Option<TestNodeWriter>,
     secondary_reader_client: Option<TestNodeReader>,
@@ -99,6 +101,8 @@ pub struct NodeFixture {
     secondary_shard_cache: Option<Arc<AsyncUnboundedShardWriterCache>>,
     tempdir: TempDir,
     secondary_tempdir: TempDir,
+    shutdown_notifier: Arc<Notify>,
+    shutdown_notified: Arc<AtomicBool>,
 }
 
 impl NodeFixture {
@@ -139,9 +143,20 @@ impl NodeFixture {
             }
         }
 
+        let shutdown_notifier = Arc::new(Notify::new());
+        let shutdown_notified = Arc::new(AtomicBool::new(false));
+
+        let shutdown_notifier_clone = Arc::clone(&shutdown_notifier);
+        let shutdown_notified_clone = Arc::clone(&shutdown_notified);
+
+        tokio::spawn(async move {
+            shutdown_notifier_clone.notified().await;
+            shutdown_notified_clone.store(true, std::sync::atomic::Ordering::Relaxed);
+        });
+
         Self {
-            settings: Arc::new(settings),
-            secondary_settings: Arc::new(secondary_settings),
+            settings: settings,
+            secondary_settings: secondary_settings,
             reader_client: None,
             writer_client: None,
             secondary_reader_client: None,
@@ -156,29 +171,39 @@ impl NodeFixture {
             secondary_shard_cache: None,
             tempdir,
             secondary_tempdir,
+            shutdown_notifier,
+            shutdown_notified,
         }
     }
 
     pub async fn with_writer(&mut self) -> anyhow::Result<&mut Self> {
         let settings = self.settings.clone();
+        let cache_settings = self.settings.clone();
         let addr = self.writer_addr;
-        let shards_cache = Arc::new(AsyncUnboundedShardWriterCache::new(settings.shards_path()));
-        self.primary_shard_cache = Some(shards_cache.clone());
+        let shards_cache = Arc::new(AsyncUnboundedShardWriterCache::new(cache_settings));
+        self.primary_shard_cache = Some(Arc::clone(&shards_cache));
+        let notifier = Arc::clone(&self.shutdown_notifier);
         self.writer_server_task = Some(tokio::spawn(async move {
-            lifecycle::initialize_writer(&settings.data_path(), &settings.shards_path())
+            lifecycle::initialize_writer(settings.clone())
                 .expect("Writer initialization has failed");
             let writer_server = NodeWriterServer::new(NodeWriterGRPCDriver::new(
                 settings.clone(),
-                shards_cache.clone(),
+                Arc::clone(&shards_cache),
             ));
             let replication_server =
                 replication::replication_service_server::ReplicationServiceServer::new(
-                    ReplicationServiceGRPCDriver::new(settings.clone(), shards_cache.clone()),
+                    ReplicationServiceGRPCDriver::new(
+                        settings.clone(),
+                        Arc::clone(&shards_cache),
+                        "primary_id".to_string(),
+                    ),
                 );
             Server::builder()
                 .add_service(writer_server)
                 .add_service(replication_server)
-                .serve(addr)
+                .serve_with_shutdown(addr, async {
+                    notifier.notified().await;
+                })
                 .await
                 .unwrap();
         }));
@@ -193,20 +218,18 @@ impl NodeFixture {
 
     pub async fn with_secondary_writer(&mut self) -> anyhow::Result<&mut Self> {
         let settings = self.secondary_settings.clone();
+        let cache_settings = self.secondary_settings.clone();
         let host_key_path = settings.host_key_path();
         let node_id = read_or_create_host_key(host_key_path)?;
-        let shards_cache = Arc::new(AsyncUnboundedShardWriterCache::new(settings.shards_path()));
+        let shards_cache = Arc::new(AsyncUnboundedShardWriterCache::new(cache_settings));
         self.secondary_shard_cache = Some(shards_cache.clone());
+        let notified = Arc::clone(&self.shutdown_notified);
         self.secondary_writer_server_task = Some(tokio::spawn(async move {
-            lifecycle::initialize_writer(&settings.data_path(), &settings.shards_path())
+            lifecycle::initialize_writer(settings.clone())
                 .expect("Writer initialization has failed");
-            connect_to_primary_and_replicate(
-                settings.clone(),
-                shards_cache.clone(),
-                node_id.to_string(),
-            )
-            .await
-            .unwrap();
+            connect_to_primary_and_replicate(settings, shards_cache, node_id.to_string(), notified)
+                .await
+                .unwrap();
         }));
 
         Ok(self)
@@ -220,9 +243,10 @@ impl NodeFixture {
         let settings = self.settings.clone();
         let addr = self.reader_addr;
 
+        let notifier = Arc::clone(&self.shutdown_notifier);
         self.reader_server_task = Some(tokio::spawn(async move {
-            lifecycle::initialize_reader();
-            let grpc_driver = NodeReaderGRPCDriver::new(Arc::clone(&settings));
+            lifecycle::initialize_reader(settings.clone());
+            let grpc_driver = NodeReaderGRPCDriver::new(settings.clone());
             grpc_driver
                 .initialize()
                 .await
@@ -230,7 +254,9 @@ impl NodeFixture {
             let reader_server = NodeReaderServer::new(grpc_driver);
             Server::builder()
                 .add_service(reader_server)
-                .serve(addr)
+                .serve_with_shutdown(addr, async {
+                    notifier.notified().await;
+                })
                 .await
                 .unwrap();
         }));
@@ -248,12 +274,13 @@ impl NodeFixture {
             self.with_secondary_writer().await?;
         }
 
-        let settings = self.secondary_settings.clone();
+        let settings = self.settings.clone();
         let addr = self.secondary_reader_addr;
+        let notifier = Arc::clone(&self.shutdown_notifier);
 
         self.reader_server_task = Some(tokio::spawn(async move {
-            lifecycle::initialize_reader();
-            let grpc_driver = NodeReaderGRPCDriver::new(Arc::clone(&settings));
+            lifecycle::initialize_reader(settings.clone());
+            let grpc_driver = NodeReaderGRPCDriver::new(settings.clone());
             grpc_driver
                 .initialize()
                 .await
@@ -261,7 +288,9 @@ impl NodeFixture {
             let reader_server = NodeReaderServer::new(grpc_driver);
             Server::builder()
                 .add_service(reader_server)
-                .serve(addr)
+                .serve_with_shutdown(addr, async {
+                    notifier.notified().await;
+                })
                 .await
                 .unwrap();
         }));
@@ -312,17 +341,6 @@ impl NodeFixture {
 
 impl Drop for NodeFixture {
     fn drop(&mut self) {
-        if let Some(task) = self.reader_server_task.take() {
-            task.abort();
-        }
-        if let Some(task) = self.writer_server_task.take() {
-            task.abort();
-        };
-        if let Some(task) = self.secondary_reader_server_task.take() {
-            task.abort();
-        };
-        if let Some(task) = self.secondary_writer_server_task.take() {
-            task.abort();
-        };
+        self.shutdown_notifier.notify_waiters();
     }
 }
