@@ -65,7 +65,7 @@ pub struct NewShardRequest {
     pub similarity: i32,
     #[prost(string, tag="2")]
     pub kbid: ::prost::alloc::string::String,
-    #[prost(enumeration="ReleaseChannel", tag="3")]
+    #[prost(enumeration="super::utils::ReleaseChannel", tag="3")]
     pub release_channel: i32,
 }
 #[derive(Clone, PartialEq, ::prost::Message)]
@@ -83,12 +83,6 @@ pub enum TypeMessage {
     Creation = 0,
     Deletion = 1,
 }
-#[derive(Clone, Copy, Debug, PartialEq, Eq, Hash, PartialOrd, Ord, ::prost::Enumeration)]
-#[repr(i32)]
-pub enum ReleaseChannel {
-    Stable = 0,
-    Experimental = 1,
-}
 /// Generated client implementations.
 pub mod node_writer_client {
     #![allow(unused_variables, dead_code, missing_docs, clippy::let_unit_value)]
