@@ -25,6 +25,7 @@ use nucliadb_core::prelude::*;
 use nucliadb_core::protos::resource::ResourceStatus;
 use nucliadb_core::protos::{DeleteGraphNodes, JoinGraph, Resource, ResourceId};
 use nucliadb_core::tracing::{self, *};
+use nucliadb_core::IndexFiles;
 use nucliadb_procs::measure;
 
 use super::utils::*;
@@ -226,8 +227,17 @@ impl WriterChild for RelationsWriterService {
     fn garbage_collection(&mut self) -> NodeResult<()> {
         Ok(())
     }
-    fn merge(&mut self) -> NodeResult<()> {
-        Ok(())
+    fn get_segment_ids(&self) -> NodeResult<Vec<String>> {
+        // not implemented, not supported right now
+        Ok(Vec::new())
+    }
+
+    fn get_index_files(&self, _ignored_segment_ids: &[String]) -> NodeResult<IndexFiles> {
+        // not implemented, not supported right now
+        Ok(IndexFiles {
+            metadata_files: HashMap::new(),
+            files: Vec::new(),
+        })
     }
 }
 
