@@ -348,7 +348,7 @@ pub struct Neighbour {
 impl Eq for Neighbour {}
 impl std::hash::Hash for Neighbour {
     fn hash<H: std::hash::Hasher>(&self, state: &mut H) {
-        self.node.hash(state);
+        self.id().hash(state)
     }
 }
 impl Ord for Neighbour {
@@ -369,10 +369,10 @@ impl PartialEq for Neighbour {
 
 impl Neighbour {
     #[cfg(test)]
-    pub fn dummy_neighbour(node: &[u8], score: f32) -> Neighbour {
+    pub fn dummy_neighbour(key: &[u8], score: f32) -> Neighbour {
         Neighbour {
             score,
-            node: node.to_vec(),
+            node: Node::serialize(key, [1, 2, 3, 4], [], None as Option<&[u8]>),
         }
     }
     fn new(Address(addr): Address, data: &[u8], score: f32) -> Neighbour {
@@ -389,16 +389,15 @@ impl Neighbour {
     pub fn id(&self) -> &[u8] {
         Node.get_key(&self.node)
     }
+    pub fn vector(&self) -> &[u8] {
+        Node::vector(&self.node)
+    }
     pub fn labels(&self) -> Vec<String> {
         Node::labels(&self.node)
     }
     pub fn metadata(&self) -> Option<&[u8]> {
         let metadata = Node::metadata(&self.node);
-        if metadata.is_empty() {
-            None
-        } else {
-            Some(metadata)
-        }
+        metadata.is_empty().then_some(metadata)
     }
 }
 
@@ -427,7 +426,7 @@ impl DataPoint {
     pub fn get_id(&self) -> DpId {
         self.journal.uid
     }
-    pub fn meta(&self) -> Journal {
+    pub fn journal(&self) -> Journal {
         self.journal
     }
     pub fn get_keys<Dlog: DeleteLog>(&self, delete_log: &Dlog) -> Vec<String> {
@@ -511,6 +510,8 @@ impl DataPoint {
             .iter()
             .map(|(dlog, dp_id)| DataPoint::open(dir, *dp_id).map(|v| (dlog, v)))
             .collect::<VectorR<Vec<_>>>()?;
+
+        // Creating the node store
         let node_producers = operants
             .iter()
             .map(|dp| ((dp.0, Node), dp.1.nodes.as_ref()));
@@ -531,6 +532,7 @@ impl DataPoint {
             (None, None)
         };
 
+        // Creating the hnsw for the new node store.
         let tracker = Retriever::new(&[], &nodes, &NoDLog, similarity, -1.0);
         let mut ops = HnswOps::new(&tracker);
         let mut index = RAMHnsw::new();
